import React from "react"
import { graphql, PageProps } from "gatsby"
import dayjs from "dayjs"

import { ArrowCircleLeftIcon } from "@heroicons/react/outline"
import {
    Badge,
    Card,
    Image,
    Button,
    Layout,
    Content,
} from "@onegeo/gatsby-theme-onegeo"

const SideBar = ({ documents, link }) => {
    return (
        <>
            {(documents?.length > 0 || link?.length > 0) && (
                <div className="w-full h-full md:w-1/4 flex flex-col bg-base-100 shadow rounded-xl min-w-min">
                    {documents?.length > 0 && (
                        <div className="pt-2 px-4 md:p-4  font-bold">
                            <p className="text-xl">Telechargements</p>
                            <div className="mt-2 font-normal">
                                {documents.map((item: any, key: number) => {
                                    return (
                                        <ul className="leading-8" key={key}>
                                            <li>
                                                {
                                                    item.directus_files_id
                                                        .filename_download
                                                }
                                            </li>
                                        </ul>
                                    )
                                })}
                            </div>
                        </div>
                    )}

                    {link?.length > 0 && (
                        <div className="px-11 pb-8 font-bold">
                            <p className="text-xl">Liens</p>
                            <div className="mt-2 font-normal">
                                {link.map((item: any) => {
                                    return (
                                        <ul className="leading-8" key={item.id}>
                                            <li>{item.links_id.url}</li>
                                        </ul>
                                    )
                                })}
                            </div>
                        </div>
                    )}
                </div>
            )}
        </>
    )
}

interface Idata {
    directus: {
        news: {
            id: string
            title: string
            date_published: string
            author: string
            image: {
                id: string
                imageFile: {
                    publicURL: string
                }
            }
            links: {
                id: string
                links_id: {
                    url: string
                }
            }
            documents: {
                directus_files_id: {
                    filename_download: string
                }
            }
            categories: {
                name: string
            }
            content: string
            link: string
        }
    }
}

const News = ({ pageContext, data, location }: PageProps<Idata>) => {
    const news = data.directus.news[0]

    const urlImage = data.directus.news[0].image?.imageFile?.publicURL
    const categoryName = data.directus.news[0].categories?.name

    const { content, title, author, link, documents, date_published } = news

    const dataPub = dayjs(date_published).format("DD/MM/YYYY")

    let position = "right"

    return (
        <Layout>
            <Content>
                <div className="flex justify-center">
                    <div className="w-5/6">
                        <div className="w-full mt-6">
                            <div className="space-y-6 lg:col-start-1 lg:col-span-2">
                                <div className="bg-base-100 shadow rounded-xl">
                                    <div className="px-4 py-5 sm:px-6">
                                        <Button
                                            aria-label="Retour"
                                            className="btn-ghost gap-2"
                                            url="/news"
                                        >
                                            <ArrowCircleLeftIcon
                                                className="h-6 w-6 mr-2"
                                                aria-hidden="true"
                                            />
                                            Retour
                                        </Button>

                                        <p className="text-xl sm:text-2xl md:text-4xl  font-bold">
                                            {title}
                                        </p>
                                        <p className=" text-sm leading-6 text-primary font-semibold tracking-wide mt-2">
                                            Soumis par {author} le {dataPub}
                                        </p>
                                        <Badge
                                            title={categoryName}
                                            className="badge-lg mt-2"
                                        />
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div className="flex mt-8 gap-8 flex-wrap md:flex-nowrap mb-8">
                            {position === "left" ? (
                                <SideBar
                                    documents={documents}
                                    link={link}
                                    // position={left}
                                />
                            ) : null}

                            <div
                                className={`w-full  ${
                                    documents?.length > 0 || link?.length > 0
                                        ? "md:w-3/4"
                                        : "w-full"
                                }`}
                            >
                                <div className="bg-base-100 shadow rounded-xl h-full">
                                    <div
                                        className="px-4 py-5 sm:px-6"
                                        style={{
                                            wordWrap: "break-word",
                                            whiteSpace: "pre-wrap",
                                            wordBreak: "break-word",
                                        }}
                                    >
                                        <div className="flex justify-center">
                                            <div className="mb-5 w-5/12">
                                                <Image image={urlImage} />
                                            </div>
                                        </div>
                                        <div
                                            data-typesense-field="description"
                                            className="my-10 text-justify"
                                            dangerouslySetInnerHTML={{
                                                __html: content,
                                            }}
                                        ></div>
                                    </div>
                                </div>
                            </div>

                            {position === "right" ? (
                                <SideBar
                                    documents={documents}
                                    link={link}
                                    // position={left}
                                />
                            ) : null}
                        </div>
                    </div>
                </div>
                <div className="flex justify-center mb-24">
                    <div className="w-5/6 flex space-x-4">
                        <Card
                            url={"/news/" + pageContext.prev?.slug}
                            name="Précédent"
                            description={pageContext.prev?.title}
                            layout="left"
                            size="xs"
                            image={
                                pageContext.prev?.image != null
                                    ? pageContext.prev?.image?.imageFile
                                          ?.publicURL
                                    : "mock"
                            }
                        />
                        {pageContext.next ? (
                            <Card
                                url={"/news/" + pageContext.next?.slug}
                                name="Suivant"
                                description={pageContext.next?.title}
                                layout="left"
                                size="xs"
                                image={
                                    pageContext.next?.image != null
                                        ? pageContext.next?.image?.imageFile
                                              ?.publicURL
                                        : "mock"
                                }
                            />
                        ) : null}
                    </div>
                </div>
            </Content>
        </Layout>
    )
}

export default News

export const query = graphql`
    query ($id: DirectusData_GraphQLStringOrFloat!) {
        directus {
            news(filter: { id: { _eq: $id } }) {
                id
                title
                content
                date_published
                author
                image {
                    id
                    imageFile {
                        publicURL
                    }
                }
                links {
                    id
                    links_id {
                        url
                    }
                }
                documents {
                    directus_files_id {
                        filename_download
                    }
                }
                categories {
                    name
                }
            }
        }
    }
`
